@@ -153,8 +153,14 @@ struct xchatprefs
 
 	int away_timeout;
 	int away_size_max;
-	int paned_pos;
-	int tabs_position;
+
+	int gui_pane_left_size;
+	int gui_pane_right_size;
+
+	int gui_ulist_pos;
+	int tab_pos;
+
+	int _tabs_position;
 	int tab_layout;
 	int max_auto_indent;
 	int dcc_blocksize;
@@ -175,6 +181,7 @@ struct xchatprefs
 	int gui_url_mod;
 	int gui_usermenu;
 	int gui_join_dialog;
+	int gui_quit_dialog;
 	int dialog_left;
 	int dialog_top;
 	int dialog_width;
@@ -273,9 +280,9 @@ struct xchatprefs
 	unsigned int wordwrap;
 	unsigned int gui_input_spell;
 	unsigned int gui_tray;
-	unsigned int _gui_tray_blink;
 	unsigned int gui_tray_flags;
-	unsigned int gui_ulist_left;
+	unsigned int gui_tweaks;
+	unsigned int _gui_ulist_left;
 	unsigned int throttle;
 	unsigned int topicbar;
 	unsigned int hideuserlist;
@@ -493,6 +500,8 @@ typedef struct server
 	int dont_use_proxy:1;		/* to proxy or not to proxy */
 	int supports_watch:1;		/* supports the WATCH command */
 	int bad_prefix:1;				/* gave us a bad PREFIX= 005 number */
+	unsigned int have_namesx:1;	/* 005 tokens NAMESX and UHNAMES */
+	unsigned int have_uhnames:1;
 	unsigned int have_whox:1;	/* have undernet's WHOX features */
 	unsigned int have_capab:1;	/* supports CAPAB (005 tells us) */
 	unsigned int have_idmsg:1;	/* freenode's IDENTIFY-MSG */
